# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import sidechain_eth_pb2 as sidechain__eth__pb2


class SidechainEthStub(object):
  """The service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.DeployEthContract = channel.unary_unary(
        '/sidechain_eth.SidechainEth/DeployEthContract',
        request_serializer=sidechain__eth__pb2.Request.SerializeToString,
        response_deserializer=sidechain__eth__pb2.Response.FromString,
        )
    self.WatchEthContract = channel.unary_unary(
        '/sidechain_eth.SidechainEth/WatchEthContract',
        request_serializer=sidechain__eth__pb2.Request.SerializeToString,
        response_deserializer=sidechain__eth__pb2.Response.FromString,
        )


class SidechainEthServicer(object):
  """The service definition.
  """

  def DeployEthContract(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchEthContract(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SidechainEthServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'DeployEthContract': grpc.unary_unary_rpc_method_handler(
          servicer.DeployEthContract,
          request_deserializer=sidechain__eth__pb2.Request.FromString,
          response_serializer=sidechain__eth__pb2.Response.SerializeToString,
      ),
      'WatchEthContract': grpc.unary_unary_rpc_method_handler(
          servicer.WatchEthContract,
          request_deserializer=sidechain__eth__pb2.Request.FromString,
          response_serializer=sidechain__eth__pb2.Response.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'sidechain_eth.SidechainEth', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
